#include "ti82.h"       ; include ash aliases
#include "keys.inc"     ; key scancodes

.org START_ADDR
.db "Minesweeper v1.0.0",0

; allocate memory
PLAYFIELD = TEXT_MEM + 1    ; playfield (12*8 bytes = 96 bytes)
                            ; goes on to TEXT_MEM + 95
XVALUE = TEXT_MEM + 97            ; XVALUE of cursor (0->11)
YVALUE = TEXT_MEM + 98            ; YVALUE of cursor (0->7)
NUMBER_OF_BOMBS = TEXT_MEM + 99   ; Number of bombs on the field
DIFFICULTY = TEXT_MEM + 100
  ; diffulty = bombs/8
  ; 1 = very easy ... 3 = normal ... 5 = very hard

; put rom page on 4 (otherwise findpixel (call $4166) won't work and
; this way PutSprite and other routines won't work...
 ld 	a,$8c			;set correct rom page for FIND_PIXEL
 OUT 	(2),A

; note on block info
; bytes : %00000000
;          ||| \--/
;          |||   |----> 4 most right bits : number from 0-8 (bombs around)
;          |||                              9 if it is a bomb
;          ||\-> 1 if revealed                                BIT 5
;          |\-> 1 if flag on top (cannot be revealed)         BIT 6
;          \-> 1 if question mark on top (cannot be revealed) BIT 7

  ; initialize DIFFICULTY to 3 (normal level)
  ld a,3
  ld (DIFFICULTY),a        ; set to normal difficulty

StartScreen:
 call CLRGBU         ; clear graph mem
  ld de,GRAPH_MEM + 3 ; displays to x= 3*8 = 24 / y = 0
  ld hl,TitlePic      ; load address of TitlePic into hl
  call PutImage       ; display title pic
  ld hl,SmallBomb
  ld bc,$2321             ; (X=35,Y=33)
  call PutSprite
 ROM_CALL(DISP_GRAPH)
  ld hl,$0814         ; (X = 20,Y = 8)
  ld (CURSOR_X),hl
  ld hl,MsgAuthor
  ROM_CALL(D_ZM_STR)  ; display my name
 ld hl,$0304
 ld (CURSOR_ROW),hl  ; (3,4)
 ld hl,MsgLeft
 ROM_CALL(D_ZT_STR)
 ld hl,$0704
 ld (CURSOR_ROW),hl  ; (7,4)
 ld hl,MsgRight
 ROM_CALL(D_ZT_STR)
  call ShowDifficulty

mainloop:
; screen where you choose the ammount of bombs
 call GET_KEY       ; wait for a keypress and returns scancode to a register
 cp G_MODE
 ret z
 cp G_CLEAR
 ret z    
 cp G_MATH
 ret z
 cp G_RIGHT      ; Right key pressed
 jr z,MoreBombs
 cp G_LEFT       ; left key pressed
 jr z,LessBombs
 cp G_ENTER
 jr z,StartGame
 jr mainloop

MoreBombs:
 ld a,(DIFFICULTY)
 cp 5
 jr z,mainloop
 inc a
 ld (DIFFICULTY),a
 call ShowDifficulty
 jr mainloop

LessBombs:
 ld a,(DIFFICULTY)
 cp 1
 jr z,mainloop
 dec a
 ld (DIFFICULTY),a
 call ShowDifficulty
 jr mainloop

StartGame:
 call CreateLevel    ; calculate playfield information
 call CLRGBU
 xor a               ; a contains X ; a = 0
 ld e,0              ; e contains Y
 ld hl,Nothing       ; contains address to sprite
 ld b,96 ; loop 96 times (8*12 = 96 tiles to draw)
DrawScreen_Loop:
 push bc
 push hl
 push af
 push de
 ld b,a
 ld c,e
 call PutSprite
 pop de
 pop af
 pop hl
 add a,8
 cp 96
 jr nz,DrawScreen_2
 ld a,e
 add a,8
 ld e,a
 xor a       ;set a back to 0
DrawScreen_2:
 pop bc
 djnz DrawScreen_Loop

;**********************
; draw line on the left
;**********************
 ld b,64     ; loop 64 times
DrawLineVer_Loop:
 push bc
 dec b
 ld c,b
 ld b,0
 call PutPixel
 pop bc
 djnz DrawLineVer_Loop
 ld b,96     ; loop 64 times
DrawLineHor_Loop:
 push bc
 dec b
 ld c,63
 call PutPixel
 pop bc
 djnz DrawLineHor_Loop

;******************
; initialize cursor
;******************
 ld hl,0
 ld (XVALUE),hl     ; put XVALUE and YVALUE to 0
 call DrawRemoveCursor

cursorloop:
; read keys & move cursor
; del/enter -> jump to RevealOne
; mode -> to main screen
; MATH -> Ash Screen
; clear -> place a flag or question mark
 call GET_KEY       ; wait for a keypress and returns scancode to a register
 cp G_MODE
 jp z,StartScreen
 cp G_MATH
 ret z
 cp G_CLEAR
 jr z,PutFlag
 cp G_RIGHT      
 jp z,MoveRight
 cp G_LEFT       
 jp z,MoveLeft
 cp G_UP         
 jp z,MoveUp
 cp G_DOWN      
 jp z,MoveDown
 cp G_DEL
 jp z,RevealOne
 cp G_ENTER
 jp z,RevealOne
 jr cursorloop

GameOver:
 ; display game over message on new screen & wait for keypress
 call DrawRemoveCursor
 call ShowAll
 ROM_CALL(DISP_GRAPH)
GameOver_Loop:
 call GET_KEY
 cp G_MODE
 ret z
 cp G_CLEAR
 ret z
 cp 0
 jr z,GameOver_Loop
 jp StartScreen

PutFlag:
 ld hl,(XVALUE)
 ld a,h
 ld h,l
 ld l,a
 call GetBlockInfo
 and %11100000
 cp %00100000        ;   <- already revealed
 jp z,cursorloop
 cp %10000000        ;   <- FLAG
 jr z,PF_Question
 cp %01000000        ;   <- Question
 jr z,PF_Nothing
 ; else, put a flag
 call GetBlockInfo
 set 7,a        ; set bit 7 of a (MSB, top left bit)
 call WriteBlockInfo
 call DrawRemoveCursor
 ld hl,SmallFlag
 call DispSprite
 call DrawRemoveCursor
 jp cursorloop
PF_Question:
 call GetBlockInfo
 xor %11000000
 call WriteBlockInfo
 call DrawRemoveCursor
 ld hl,SmallQuestion
 call DispSprite
 call DrawRemoveCursor
 jp cursorloop
PF_Nothing:
 call GetBlockInfo
 res 6,a ; unset bit 6 of a (bit 7 was not set, bit 6 was)
         ; bits are numbers from right to left : 7 ... 0
         ; so I need the 2nd bit from the left
 call WriteBlockInfo
 call DrawRemoveCursor
 ld hl,SmallNothing
 call DispSprite
 call DrawRemoveCursor
 jp cursorloop

RevealOne:           ; reveal the contents of a spot on the map
 ld hl,(XVALUE)
 ld a,h
 ld h,l
 ld l,a
 call GetBlockInfo   ;     -> Blockinfo in A
 and %11100000 ; if already revealed or question mark/flag on top, don't go on
 cp 0
 jp nz,cursorloop
 call GetBlockInfo   ;     -> Blockinfo in A
 and %00001111       ;     -> mask out 4 MSB's
 set 5,a             ;     -> set revealed on
 call WriteBlockInfo ;     -> Write Blockinfo
 res 5,a             ;     0000 0000 <- example byte
                     ;     7654 3210 <- number of bit  
 cp %00001001        ;     -> check if we have a bomb
 jr nz, DispNumber
 ; BOMB
 call DrawRemoveCursor
 ld hl,SmallBomb
 call DispSprite
 call DrawRemoveCursor
 jp GameOver
DispNumber:
 call GetBlockInfo   ;     -> Blockinfo in A
 and %00001111
 ld b,a
 call DrawRemoveCursor
 ld hl,Small0
 cp 0
 jr z,DispNumber_2
 ld de,8
DispNumber_1:
 add hl,de
 djnz DispNumber_1
DispNumber_2:
 call DispSprite
 call DrawRemoveCursor
 ; NOW CHECK IF PLAYER HAS WON THE GAME
 ld c,0
 ld b,96
 ld hl,PLAYFIELD
CheckIfWonLoop:
 ld a,(hl)
 and %00100000
 cp 0
 jr nz,CheckNext
 inc c
CheckNext:
 inc hl
 djnz CheckIfWonLoop
 ld a,(NUMBER_OF_BOMBS)
 cp c
 jr z,PlayerHasWon
 jp cursorloop

MoveLeft:
 call DrawRemoveCursor
 ld a,(XVALUE)
 dec a
 ld (XVALUE),a
 cp -1
 jr nz,MoveIt
 inc a
 ld (XVALUE),a
 jr MoveIt
MoveRight:
 call DrawRemoveCursor
 ld a,(XVALUE)
 inc a
 ld (XVALUE),a
 cp 12
 jr nz,MoveIt
 dec a
 ld (XVALUE),a
 jr MoveIt
MoveUp:
 call DrawRemoveCursor
 ld a,(YVALUE)
 dec a
 ld (YVALUE),a
 cp -1                       
 jr nz,MoveIt
 inc a
 ld (YVALUE),a
 jr MoveIt
MoveDown:
 call DrawRemoveCursor
 ld a,(YVALUE)
 inc a
 ld (YVALUE),a
 cp 8                        
 jr nz,MoveIt
 dec a
 ld (YVALUE),a
MoveIt:
 call DrawRemoveCursor
 jp cursorloop

PlayerHasWon:
 ; display winner message on new screen & wait for keypress
 ROM_CALL(CLEARLCD)
 ld hl,$0403              
 ld (CURSOR_ROW),hl
 ld hl,MsgWon1
 ROM_CALL(D_ZT_STR)
 ld hl,$0404
 ld (CURSOR_ROW),hl
 ld hl,MsgWon2
 ROM_CALL(D_ZT_STR)
 jp GameOver_Loop  ; wait for key (=wait for key)

GetBlockInfo:
; input : h = X value (0-11)
;         l = Y value (0-7)
; returns : block info in a
 call CalculateAddress
 ld a,(de)
 ret  

CalculateAddress:
 ; input : h = X value (0-11)
 ;         l = Y value (0-7)
 ; returns : address of blockinfo in de
 push hl
 push bc
 ld a,l                        ; a contains y value (0-7)
 ld b,a                        ; b contains y value (0-7)
 push hl                       ; push hl to save x and y value for later
 ld hl,PLAYFIELD               ; address of playfield in hl
 cp 0                          ; cp a (y value) to 0
 jr z,CalcAddr_GoOn            ; if y = 0 then goto CalcAddr_GoOn ( la Basic)
 ld de,12                      ; de = 12
CalcAddr_Loop:                 ; loop b times (= y value)
 add hl,de                     ; increase hl with 12 bytes (1 row down)
 djnz CalcAddr_Loop
CalcAddr_GoOn:
 pop de                        ; get x and y values back from stack
                               ; but in 'de' this time
                               ; d = x (0-11)
                               ; e = y (0-7)
 ld e,d                        ; e contains x value
 ld d,0                        ; d contains 0 -> de contains x value
 add hl,de                     ; increase hl with de (x value)
 ex de,hl                      ; exchange de and hl
 pop bc
 pop hl
 ret

WriteBlockInfo:
; input : h = X value (0-11)
;         l = Y value (0-7)
;         a = block info
 push af
 call CalculateAddress
 pop af
 ld (de),a
 ret

DrawRemoveCursor: ; draws or removes the cursor  
 push hl
 push af
 push bc
 ld a,(XVALUE)                             
 add a,a    ; *2                           
 add a,a    ; *4                           
 add a,a    ; *8                           
 ld h,a              ; X in h              
 ld a,(YVALUE)                             
 add a,a    ; *2                           
 add a,a    ; *4                           
 add a,a    ; *8                           
 ld l,a              ; Y in l              
 ld b,8                   ; loop 8 times
DRCursor_Loop1:
 push bc                  ; push 1
 ld b,8                           ; loop 8 times
DRCursor_Loop2:                   
 push bc                          ; push 2
 dec b
 ld a,h                           
 add a,b
 ld b,a    ; X = X + 7..0
 ld c,l    ; Y in c
 ld a,63
 sub c     ; a=a-c (y=63-y)     (needed for find_pixel)
 ld c,a
 push hl                              ; push 3
 call ChangePixel  
 pop hl                               ; pop 3
 pop bc                           ; pop 2
 djnz DRCursor_Loop2              ; end of loop2
 pop bc                   ; pop 1
 inc l          ; make ready for next row (Y+1)
 djnz DRCursor_Loop1      ; end of loop 1
 ROM_CALL(DISP_GRAPH) ; Display Graph Mem to display !
 pop bc
 pop af
 pop hl
 ret

CreateLevel:
 ; **************************************
 ; clean PLAYFIELD !!! (Fill with zero's)
 ; **************************************
 xor a              ; load 0 into A register
 ld hl,PLAYFIELD
 ld b,96
CL_ClearPlayfield:
 ld (hl),a
 inc hl
 djnz CL_ClearPlayfield
 ; ***************************************************************
 ; multiply NUMBER_OF_BOMBS with 8 (to get actual amount of bombs)
 ; ***************************************************************
 ld a,(DIFFICULTY)
 add a,a ; *2
 add a,a ; *4
 add a,a ; *8
 ld (NUMBER_OF_BOMBS),a
 ; ******************************************************
 ; now, put the bombs in the first bytes of the playfield
 ; ******************************************************
 ld hl,PLAYFIELD
 ld b,a
 ld a,%00001001  ;  (=9 -> BOMB !)
CL_Loop:
 ld (hl),a
 inc hl
 djnz CL_Loop
 ; *******************************************************
 ; Now let's shuffle the playfield so the bombs get spread
 ; *******************************************************
 ld b,10
Sh_Loop:
 push bc
 ld b,12
Sh_L1:
 push bc
   dec b
   ld h,b       ; X
   ld b,8
Sh_L2:
   push bc
    dec b
    ld l,b       ; Y
    call GetBlockInfo      ; blockinfo 1 in a
    ld b,a                 ; blockinfo 1 in b
    push hl
    ld a,12
    call Random
    ld h,a
    ld a,8
    call Random
    ld l,a
    call GetBlockInfo      ; blockinfo 2 in a
    ld c,a                 ; blockinfo 2 in c
    ld a,b                 ; blockinfo 1 in a
    call WriteBlockInfo
    pop hl                 ; coords 1 in hl
    ld a,c                 ; blockinfo 2 in a
    call WriteBlockInfo
   pop bc
   djnz Sh_L2
 pop bc
 djnz Sh_L1
 pop bc
 djnz Sh_Loop
 ; ***************************************************
 ; NOW, CALCULATE THE NUMBER OF BOMBS AROUND EACH SPOT
 ; ***************************************************
 ld b,12
Calc_Bombs_Loop1:
 push bc
 dec b
 ld h,b                        ; h contains X
   ld b,8
Calc_Bombs_Loop2:
   push bc
   dec b
   ld l,b                        ; b contains Y
   call GetBlockInfo             ; blockinfo in a
   and %00001111
   cp 9        ; don't try if we have a bomb (duh)
   jr z,NextPiece                        ;  1 2 3
   push hl                               ;  4 X 6    X = place where
   dec l                                 ;  7 8 9        we check
   ld b,0                ; bomb counter to zero
   dec h                                     
   call CheckBomb                        ; 1
   inc l
   call CheckBomb                        ; 4
   inc l
   call CheckBomb                        ; 7
   inc h
   dec l
   dec l
   call CheckBomb                        ; 2
   inc l
   inc l
   call CheckBomb                        ; 8
   inc h
   dec l
   dec l
   call CheckBomb                        ; 3
   inc l
   call CheckBomb                        ; 6
   inc l
   call CheckBomb                        ; 9
   dec l
   dec l
   pop hl
   ld a,b
   call WriteBlockInfo
NextPiece:
   pop bc
   djnz Calc_Bombs_Loop2
 pop bc
 djnz Calc_Bombs_Loop1
 ret        ; end of createlevel (at last)

CheckBomb:
 ; first, check if h and l (x and y) aren't out of the playfield
 ld a,h        ; if that's the problem, return
 cp -1
 ret z
 cp 12
 ret z
 ld a,l
 cp -1
 ret z
 cp 8
 ret z
 call GetBlockInfo
 and %00001111
 cp 9
 ret nz
 inc b       ; only if we have a bomb (we use b as the bomb counter)
 ret

ShowDifficulty:
 ld hl,$0305
 ld (CURSOR_ROW),hl  ; (X=3,Y=5)
 ld hl,MsgDifficulty
 ld a,(DIFFICULTY)
 dec a
 cp 0
 jr z,SD_LoopDone
 ld de,11 
 ld b,a
 xor a             ; ld a,0
SD_Loop:
 add hl,de
 add a,3             ; we will use this later
 djnz SD_Loop
SD_LoopDone:
 push af
 ROM_CALL(D_ZT_STR)
 pop af
 ld hl,$0804
 ld (CURSOR_ROW),hl  ; (X=8,Y=4)
 ld hl,MsgNrBombs
 ld e,a
 ld d,0
 add hl,de              ; should now contain address for number of bombs string
 ROM_CALL(D_ZT_STR)
 ret

DispSprite:       ; address in HL (X and Y in XVALUE and YVALUE)
 ld a,(XVALUE)
 add a,a ;* 2
 add a,a ;* 4
 add a,a ;* 8
 inc a
 ld b,a
 ld a,(YVALUE)
 add a,a ;*2
 add a,a ;*4
 add a,a ;*8
 inc a
 ld c,a
 call PutSprite
 ret

ShowAll:
 ld hl,PLAYFIELD
 ld d,0
 ld e,0
 ld b,96 ; (loop 96 times)
ShowAll_Loop:
 push bc
 push hl
 ld a,(hl)
 and %00001111
 cp 9
 jr nz, SA_Next
  ld a,d
  ld (XVALUE),a
  ld a,e
  ld (YVALUE),a
  ld hl,SmallBomb
  call DispSprite
SA_Next:
 pop hl
 inc hl
 inc d
 ld a,d
 cp 12
 jr nz,SA_Next2
 ld d,0
 inc e
SA_Next2:
 pop bc
 djnz ShowAll_Loop
 ret

; -----------------------------------------------------------------------
; | START OF ROUTINES NOT WRITTEN BY ME                                 |
; -----------------------------------------------------------------------

ChangePixel:      ; Changes the pixel at B,C
 CALL FIND_PIXEL           ; Jimmy Mardell
 ld de,GRAPH_MEM
 add hl,de
 xor (hl)
 ld (hl),a
 ret

PutPixel: ; Puts a pixel at B,C
 CALL FIND_PIXEL           ; Jimmy Mardell
 ld de,GRAPH_MEM
 add hl,de
 or (hl)
 ld (hl),a
 ret

CLRGBU:                    ; written by ??
 ld 	hl,GRAPH_MEM
 ld 	de,GRAPH_MEM+1
 ld 	bc,768
 ld 	(hl),0
 ldir
 ret

PutImage:       ; Copies picture in (hl) to address de in GRAPH_MEM
  ld  b,(hl)    ; see Ash Online School Lesson 5
  inc hl                         ; Jimmy Mardell
	ld	c,(hl)
	inc	hl
pi_newrow:
	push	bc
	push	de
pi_newcol:
	ld	a,(hl)
	inc	hl
	ld	(de),a
	inc	de
	djnz	pi_newcol
	pop	de
	ld	bc,12
	ex	de,hl
	add	hl,bc
	ex	de,hl
	pop	bc
	dec	c
	jr	nz,pi_newrow
	ROM_CALL(DISP_GRAPH)
	ret

PutSprite: ; Puts a sprite stored at (HL) at B,C  (by Jimmy Mardell)
 push 	bc
 push 	de
 ld 	a,63
 sub 	c
 ld 	c,a
 push 	hl
 push 	hl
 call   $4166            ;find pixel
 ld 	de,$88B8
 add 	hl,de
 ex 	de,hl
 pop 	hl
 ld 	b,(hl)
 inc 	hl
 ld 	c,(hl)
 inc 	hl
 push 	hl
 pop 	ix
 ex 	de,hl
PS_NewRow:
 push 	bc
 ld 	d,(ix)
 inc 	ix
 push 	af
 push 	hl
PS_NewCol:
 rl 	d
 ld 	e,a
 jr 	nc,PS_NoPixel
 or 	(hl)
 ld 	(hl),a
 jr 	PS_NextPixel
PS_NoPixel:
 cpl
 and 	(hl)
 ld 	(hl),a
PS_NextPixel:
 ld 	a,e
 rrca
 jr 	nc,PS_SameByte
 inc 	hl
PS_SameByte:
 djnz 	PS_NewCol
 pop 	hl
 pop 	af
 ld 	de,12
 add 	hl,de
 pop 	bc
 dec 	c
 jr 	nz,PS_NewRow
 pop 	hl
 pop 	de
 pop 	bc
 ret

Random:
  ; Routine by Jimmy Mardell  
  ; input  : A     (0 <= x < A) with x the random number to get
  ; output : A is random number
  push  bc     
	push	de
	push	hl
	ld	b,a
	ld	a,r
	add	a,a
	ld	hl,0
	ld	d,0
	ld	e,a
RMul:
	add	hl,de
	djnz	RMul
	ld	a,h
	pop	hl
	pop	de
	pop	bc
  ret       

; -----------------------------------------------------------------------
; |    PROGRAM DATA (SPRITES/PICTURES/TEXT)                             |
; -----------------------------------------------------------------------

TitlePic: ; MineS title
.db 7,8
.db %00011100,%01110000,%00110000,%00000000,%00000000,%00000011,%11100000
.db %00110110,%11011000,%00110000,%00000000,%00000000,%00000110,%01100000
.db %01100011,%10001100,%00000000,%10111000,%00001111,%00001100,%00000000
.db %01100011,%10001100,%00111000,%11101100,%00011001,%10001100,%00000000
.db %01100001,%00001100,%00110000,%11000110,%00110000,%10000111,%11000000
.db %01100000,%00001100,%00110000,%11000110,%00111111,%00000000,%01100000
.db %01100000,%00001100,%00110000,%11000110,%00011000,%01001100,%01100000
.db %11110000,%00011110,%01111001,%11101111,%00001111,%11001111,%11000000

SmallBomb:  ; (6*6 sprite)
.db 6,6
.db %00011000
.db %00100000
.db %01110000
.db %11111000
.db %11111000
.db %01110000

SmallFlag:   ; (6,6 sprite)
.db 6,6
.db %11111000
.db %11111000
.db %11111000
.db %00001000
.db %00001000
.db %00011100

SmallNothing: ;(6,6 sprite)
.db 6,6
.db %00000000
.db %00000000
.db %00000000
.db %00000000
.db %00000000
.db %00000000

SmallQuestion: ;(6,6 sprite)
.db 6,6
.db %01110000
.db %10001000
.db %00010000
.db %00100000
.db %00000000
.db %00100000

Small0: ;(6,6 sprite)
.db 6,6
.db %01110000
.db %10001000
.db %10001000
.db %10001000
.db %10001000
.db %01110000
Small1: ;(6,6 sprite)
.db 6,6
.db %00100000
.db %01100000
.db %00100000
.db %00100000
.db %00100000
.db %01110000
Small2: ;(6,6 sprite)
.db 6,6
.db %01110000
.db %10001000
.db %00001000
.db %00110000
.db %01000000
.db %11111000
Small3: ;(6,6 sprite)
.db 6,6
.db %11111000
.db %00010000
.db %00100000
.db %00010000
.db %10001000
.db %01110000
Small4: ;(6,6 sprite)
.db 6,6
.db %00010000
.db %00110000
.db %01010000
.db %11111000
.db %00010000
.db %00010000
Small5: ;(6,6 sprite)
.db 6,6
.db %11111000
.db %10000000
.db %11110000
.db %00001000
.db %00001000
.db %11110000
Small6: ;(6,6 sprite)
.db 6,6
.db %01111000
.db %10000000
.db %11110000
.db %10001000
.db %10001000
.db %01110000
Small7: ;(6,6 sprite)
.db 6,6
.db %11111000
.db %00001000
.db %00010000
.db %00100000
.db %01000000
.db %01000000
Small8: ;(6,6 sprite)
.db 6,6
.db %01110000
.db %10001000
.db %01110000
.db %10001000
.db %10001000
.db %01110000

Nothing:   ; (8,8 sprite)
.db 8,8
.db %00000001
.db %00000001
.db %00000001
.db %00000001
.db %00000001
.db %00000001
.db %00000001
.db %11111111


MsgAuthor:
.db "Wouter Demuynck",0
MsgDifficulty:
.db " Too Easy ",0                ; 8 bombs
.db "   Easy   ",0                ; 16 bombs
.db "  Normal  ",0                ; 24 bombs
.db "   Hard   ",0                ; 32 bombs
.db "Impossible",0                ; 40 bombs
MsgNrBombs:
.db "8 ",0
.db "16",0
.db "24",0
.db "32",0
.db "40",0
MsgLeft:
.db "<-",0
MsgRight:
.db "x   ->",0
MsgWon1:
.db "Well Done,",0
MsgWon2:
.db "You Won !",0

.end

